From 243bfdcb37ac5ea25904a0f536677fe1c5d6ca9f Mon Sep 17 00:00:00 2001
From: erankor <eran.kornblau@kaltura.com>
Date: Wed, 19 Jan 2022 09:04:35 +0200
Subject: [PATCH] http: remove cache_redirect option

following 625ea2d, redirect caching is performed according to the http
response headers, there's no need to have it as an option -
always start from the original uri, and apply any redirects according
to the redirect_cache dictionary.
---
 libavformat/http.c    | 6 ++----
 libavformat/version.h | 1 -
 2 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/libavformat/http.c b/libavformat/http.c
index cf04d3f14f..e8096e3134 100644
--- a/libavformat/http.c
+++ b/libavformat/http.c
@@ -72,7 +72,6 @@ typedef struct HTTPContext {
     uint64_t off, end_off, filesize;
     char *uri;
     char *location;
-    int cache_redirect;
     HTTPAuthState auth_state;
     HTTPAuthState proxy_auth_state;
     char *http_proxy;
@@ -175,7 +174,6 @@ static const AVOption options[] = {
     { "resource", "The resource requested by a client", OFFSET(resource), AV_OPT_TYPE_STRING, { .str = NULL }, 0, 0, E },
     { "reply_code", "The http status code to return to a client", OFFSET(reply_code), AV_OPT_TYPE_INT, { .i64 = 200}, INT_MIN, 599, E},
     { "short_seek_size", "Threshold to favor readahead over seek.", OFFSET(short_seek_size), AV_OPT_TYPE_INT, { .i64 = 0 }, 0, INT_MAX, D },
-    { "cache_redirect", "Save redirected URL for subsequent seek operations", OFFSET(cache_redirect), AV_OPT_TYPE_BOOL, { .i64 = FF_HTTP_CACHE_REDIRECT_DEFAULT }, 0, 1, D },
     { NULL }
 };
 
@@ -1938,8 +1936,8 @@ static int64_t http_seek_internal(URLContext *h, int64_t off, int whence, int fo
             return s->off;
     }
 
-    /* if redirect caching is disabled, revert to the original uri */
-    if (!s->cache_redirect && strcmp(s->uri, s->location)) {
+    /* if the location changed (redirect), revert to the original uri */
+    if (strcmp(s->uri, s->location)) {
         char *new_uri;
         new_uri = av_strdup(s->uri);
         if (!new_uri)
diff --git a/libavformat/version.h b/libavformat/version.h
index bd014e907e..5439dad170 100644
--- a/libavformat/version.h
+++ b/libavformat/version.h
@@ -60,7 +60,6 @@
 #define FF_API_AVIOCONTEXT_WRITTEN      (LIBAVFORMAT_VERSION_MAJOR < 60)
 #define FF_HLS_TS_OPTIONS               (LIBAVFORMAT_VERSION_MAJOR < 60)
 #define FF_API_AVSTREAM_CLASS           (LIBAVFORMAT_VERSION_MAJOR > 59)
-#define FF_HTTP_CACHE_REDIRECT_DEFAULT  (LIBAVFORMAT_VERSION_MAJOR < 60)
 
 
 #define FF_API_R_FRAME_RATE            1
-- 
2.29.2.windows.4

